==> polls-v1.4.1.zip: polls/messages/pt/base.php <==
<?php

return [
    '<strong>Note:</strong> The result is hidden until the poll is closed by a moderator.' => '<strong>Nota:</strong> O resultado está oculto até a votação ser fechada pela moderação.',
    'Access denied!' => 'Acesso negado!',
    'Add answer...' => 'Adicionar opção...',
    'Again? ;Weary;' => 'Outra vez? ;cansado;',
    'Allows the user to create polls' => 'Permite à pessoa criar votações',
    'Allows to start polls.' => 'Permite iniciar votações.',
    'Anonymous' => 'Anónimo',
    'Anonymous Votes?' => 'Votos anónimos?',
    'Anonymous poll!' => 'Votação anónima!',
    'Answers' => 'Opções',
    'At least one answer is required' => 'Pelo menos uma opção é necessária',
    'Cancel' => 'Cancelar',
    'Close Poll' => 'Votação completa',
    'Closed' => 'Fechada',
    'Club A Steakhouse' => 'Churrasqueira Club A',
    'Could not load poll!' => 'Não conseguimos carregar a votação!',
    'Create poll' => 'Criar votação',
    'Description' => 'Descrição',
    'Display answers in random order?' => 'Ordenar opções aleatoriamente?',
    'Edit answer (empty answers will be removed)...' => 'Editar opção (opções vazias serão removidas)...',
    'Edit your poll question...' => 'Editar questão da votação...',
    'Hide results until poll is closed?' => 'Resultados só divulgados no fim da votação',
    'Invalid answer!' => 'Resposta não válida!',
    'Location of the next meeting' => 'Local da próxima reunião',
    'Multiple answers per user' => 'Várias opções por membro',
    'Pisillo Italian Panini' => 'Pisillo Panini italiano',
    'Please specify at least {min} answers!' => 'Por favor, especifica pelo menos {min} opções!',
    'Poll' => 'Votação',
    'Polls' => 'Votações',
    'Question' => 'Questão',
    'Reopen Poll' => 'Reabrir votação',
    'Reset my vote' => 'Mudar o meu voto',
    'Right now, we are in the planning stages for our next meetup and we would like to know from you, where you would like to go?' => 'Neste momento, estamos na fase de planeamento do nosso próximo encontro e gostávamos de saber de ti, onde gostarias de ir?',
    'Save' => 'Guardar',
    'To Daniel' => 'Para o Daniel',
    'Users voted for: <strong>{answer}</strong>' => 'Votou-se: <strong>{answer}</strong>',
    'Vote' => 'Voto',
    'Voting for multiple answers is disabled!' => 'Votação aberta a várias opções desactivada!',
    'Whenever someone participates in a poll.' => 'Quando alguém participa numa votação.',
    'Why don\'t we go to Bemelmans Bar?' => 'Porque é que não vamos ao Bar Bemelmans?',
    'You have insufficient permissions to perform that operation!' => 'Não tens permissões suficientes para executar esta operação!',
    'and {count} more vote for this.' => 'e {count} votaram para esta opção.',
    'votes' => 'votos',
    '{userName} answered the {question}.' => '{userName} votou sobre {question}.',
    'Poll content ID' => '',
    '{n,plural,=1{# {htmlTagBegin}vote{htmlTagEnd}}other{# {htmlTagBegin}votes{htmlTagEnd}}}' => '',
];

==> polls-v1.4.2.zip: polls/messages/pt/base.php <==
<?php

return [
    '<strong>Note:</strong> The result is hidden until the poll is closed by a moderator.' => '<strong>Nota:</strong> O resultado está oculto até a votação ser fechada pela moderação.',
    'Access denied!' => 'Acesso negado!',
    'Add answer...' => 'Adicionar opção...',
    'Again? :weary:' => 'Outra vez? ;cansado;',
    'Allows the user to create polls' => 'Permite à pessoa criar votações',
    'Allows to start polls.' => 'Permite iniciar votações.',
    'Anonymous' => 'Anónimo',
    'Anonymous Votes?' => 'Votos anónimos?',
    'Anonymous poll!' => 'Votação anónima!',
    'Answers' => 'Opções',
    'At least one answer is required' => 'Pelo menos uma opção é necessária',
    'Cancel' => 'Cancelar',
    'Close Poll' => 'Votação completa',
    'Closed' => 'Fechada',
    'Club A Steakhouse' => 'Churrasqueira Club A',
    'Could not load poll!' => 'Não conseguimos carregar a votação!',
    'Create poll' => 'Criar votação',
    'Description' => 'Descrição',
    'Display answers in random order?' => 'Ordenar opções aleatoriamente?',
    'Edit answer (empty answers will be removed)...' => 'Editar opção (opções vazias serão removidas)...',
    'Edit your poll question...' => 'Editar questão da votação...',
    'Hide results until poll is closed?' => 'Resultados só divulgados no fim da votação',
    'Invalid answer!' => 'Resposta não válida!',
    'Location of the next meeting' => 'Local da próxima reunião',
    'Multiple answers per user' => 'Várias opções por membro',
    'Pisillo Italian Panini' => 'Pisillo Panini italiano',
    'Please specify at least {min} answers!' => 'Por favor, especifica pelo menos {min} opções!',
    'Poll' => 'Votação',
    'Polls' => 'Votações',
    'Question' => 'Questão',
    'Reopen Poll' => 'Reabrir votação',
    'Reset my vote' => 'Mudar o meu voto',
    'Right now, we are in the planning stages for our next meetup and we would like to know from you, where you would like to go?' => 'Neste momento, estamos na fase de planeamento do nosso próximo encontro e gostávamos de saber de ti, onde gostarias de ir?',
    'Save' => 'Guardar',
    'To Daniel' => 'Para o Daniel',
    'Users voted for: <strong>{answer}</strong>' => 'Votou-se: <strong>{answer}</strong>',
    'Vote' => 'Voto',
    'Voting for multiple answers is disabled!' => 'Votação aberta a várias opções desactivada!',
    'Whenever someone participates in a poll.' => 'Quando alguém participa numa votação.',
    'Why don\'t we go to Bemelmans Bar?' => 'Porque é que não vamos ao Bar Bemelmans?',
    'You have insufficient permissions to perform that operation!' => 'Não tens permissões suficientes para executar esta operação!',
    'and {count} more vote for this.' => 'e {count} votaram para esta opção.',
    'votes' => 'votos',
    '{userName} answered the {question}.' => '{userName} votou sobre {question}.',
    'Poll content ID' => '',
    '{n,plural,=1{# {htmlTagBegin}vote{htmlTagEnd}}other{# {htmlTagBegin}votes{htmlTagEnd}}}' => '',
];
